window.Gleam.initSearch([{"doc":"sketch_redraw","title":"sketch_redraw","content":"# Sketch Redraw\n\n&gt; In case you&#39;re here and don&#39;t know Sketch, take a look at\n&gt; [`sketch` package](https://hexdocs.pm/sketch)!\n\n&gt; This readme is a carbon-copy of the Sketch Redraw section in `sketch` readme.\n\n## Setup\n\nWhen you&#39;re using Redraw, `sketch_redraw` covers you. `sketch_redraw` exposes\none entrypoint, `sketch/redraw`, containing everything needed to get started.\n\n```gleam\n// main.gleam\nimport redraw\nimport sketch/redraw as sketch_redraw\n\npub fn main() {\n  let root = client.create_root(&quot;root&quot;)\n  client.render(root,\n    redraw.strict_mode([\n      // Initialise the cache. Sketch Redraw handles the details for you.\n      sketch_redraw.provider([\n        // Here comes your components!\n      ])\n    ])\n  )\n}\n```\n\n## Usage\n\n`sketch_redraw` exposes one module to help you build your site, similarly to\nredraw: `sketch/redraw/dom/html`. `html` is simply a supercharged component,\naccepting a `sketch.Class` as first argument, and applies that style to the\nnode. Because it&#39;s a simple component, `sketch/redraw/dom/html` and\n`redraw/html` can be mixed in the same code without issue! Because of that\nproperty, `sketch_redraw` _does not_ expose `text` and `none` function at that\ntime.\n\n```gleam\nimport redraw/html as h\nimport sketch/css\nimport sketch/css/length.{px}\nimport sketch/redraw/html\n\nfn main_style() {\n  css.class([\n    css.background(&quot;red&quot;),\n    css.font_size(px(16)),\n  ])\n}\n\nfn view(model: Int) {\n  html.div(main_style(), [], [\n    h.div([], [\n      h.text(int.to_string(model))\n    ]),\n  ])\n}\n```\n\nAnd you&#39;re done! Enjoy your Redraw app, Sketch-enhanced!\n\n## Final notes\n\nSketch Redraw tries to integrate nicely with React Devtools! In case you&#39;re\nseeing something weird, signal the bug!\n","url":"index.html"},{"doc":"sketch/redraw","title":"provider","content":"pub fn provider(children: List(Component)) -&gt; Component\n Create the Sketch provider used to manage the `StyleSheet`. \\\n This makes sure identical styles will never be computed twice. \\\n Use it at root of your render function.\n\n \n import redraw\n import redraw/dom/client\n import sketch/redraw as sketch_redraw\n\n pub fn main() {\n   let app = app()\n   let root = client.create_root(&quot;root&quot;)\n   client.render(root, {\n     redraw.strict_mode([\n       sketch_redraw.provider([\n         app(),\n       ]),\n     ])\n   })\n }\n \nSynonyms:\nsketch/redraw.provider\nsketch/redraw provider","url":"sketch/redraw.html#provider"},{"doc":"sketch/redraw","title":"sketch/redraw","content":"","url":"sketch/redraw.html"},{"doc":"sketch/redraw/dom/html","title":"a","content":"pub fn a(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;a&gt;` HTML element (or anchor element), with [its `href` attribute](https://developer.mozilla.org/docs/Web/HTML/Element/a#href),\n creates a hyperlink to web pages, files, email addresses, locations in the\n same page, or anything else a URL can address.\n\n Content within each `&lt;a&gt;` should indicate the link&#39;s destination. If the\n `href` attribute is present, pressing the enter key while focused on the\n `&lt;a&gt;` element will activate it.\n\n You can use [`modem`](https://hexdocs.pm/modem/) to manage internal linking\n in your Lustre application.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/a)\nSynonyms:\nsketch/redraw/dom/html.a\nsketch/redraw/dom/html a","url":"sketch/redraw/dom/html.html#a"},{"doc":"sketch/redraw/dom/html","title":"abbr","content":"pub fn abbr(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;abbr&gt;` HTML element represents an abbreviation or acronym.\n\n When including an abbreviation or acronym, provide a full expansion of the\n term in plain text on first use, along with the `&lt;abbr&gt;` to mark up the\n abbreviation. This informs the user what the abbreviation or acronym means.\n\n The optional `title` attribute can provide an expansion for the abbreviation\n or acronym when a full expansion is not present. This provides a hint to\n user agents on how to announce/display the content while informing all users\n what the abbreviation means. If present, `title` must contain this full\n description and nothing else.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/abbr)\nSynonyms:\nsketch/redraw/dom/html.abbr\nsketch/redraw/dom/html abbr","url":"sketch/redraw/dom/html.html#abbr"},{"doc":"sketch/redraw/dom/html","title":"address","content":"pub fn address(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;address&gt;` HTML element indicates that the enclosed HTML provides\n contact information for a person or people, or for an organization.\n\n The contact information provided by an `&lt;address&gt;` element&#39;s contents can\n take whatever form is appropriate for the context, and may include any type\n  of contact information that is needed, such as a physical address, URL,\n  email address, phone number, social media handle, geographic coordinates,\n and so forth. The `&lt;address&gt;` element should include the name of the person,\n people, or organization to which the contact information refers.\n\n `&lt;address&gt;` can be used in a variety of contexts, such as providing a\n business&#39;s contact information in the page header, or indicating the author\n of an article by including an `&lt;address&gt;` element within the `&lt;article&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/address)\nSynonyms:\nsketch/redraw/dom/html.address\nsketch/redraw/dom/html address","url":"sketch/redraw/dom/html.html#address"},{"doc":"sketch/redraw/dom/html","title":"area","content":"pub fn area(\n  class: Class,\n  attributes: List(Attribute),\n) -&gt; Component\n The `&lt;area&gt;` HTML element defines an area inside an image map that has\n predefined clickable areas. An image map allows geometric areas on an\n image to be associated with hypertext links.\n\n This element is used only within a `&lt;map&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/area)\nSynonyms:\nsketch/redraw/dom/html.area\nsketch/redraw/dom/html area","url":"sketch/redraw/dom/html.html#area"},{"doc":"sketch/redraw/dom/html","title":"article","content":"pub fn article(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;article&gt;` HTML element represents a self-contained composition in a\n document, page, application, or site, which is intended to be independently\n distributable or reusable (e.g., in syndication). Examples include: a forum\n post, a magazine or newspaper article, or a blog entry, a product card, a\n user-submitted comment, an interactive widget or gadget, or any other\n independent item of content.\n\n A given document can have multiple articles in it; for example, on a blog\n that shows the text of each article one after another as the reader scrolls,\n each post would be contained in an `&lt;article&gt;` element, possibly with one\n or more `&lt;section&gt;`s within.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/article)\nSynonyms:\nsketch/redraw/dom/html.article\nsketch/redraw/dom/html article","url":"sketch/redraw/dom/html.html#article"},{"doc":"sketch/redraw/dom/html","title":"aside","content":"pub fn aside(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;aside&gt;` HTML element represents a portion of a document whose content\n is only indirectly related to the document&#39;s main content. Asides are f\n requently presented as sidebars or call-out boxes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/aside)\nSynonyms:\nsketch/redraw/dom/html.aside\nsketch/redraw/dom/html aside","url":"sketch/redraw/dom/html.html#aside"},{"doc":"sketch/redraw/dom/html","title":"audio","content":"pub fn audio(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;audio&gt;` HTML element is used to embed sound content in documents. It\n may contain one or more audio sources, represented using the src attribute\n or the `&lt;source&gt;` element: the browser will choose the most suitable one. It\n can also be the destination for streamed media, using a `MediaStream`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/audio)\nSynonyms:\nsketch/redraw/dom/html.audio\nsketch/redraw/dom/html audio","url":"sketch/redraw/dom/html.html#audio"},{"doc":"sketch/redraw/dom/html","title":"b","content":"pub fn b(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;b&gt;` HTML element is used to draw the reader&#39;s attention to the\n element&#39;s contents, which are not otherwise granted special importance.\n This was formerly known as the Boldface element, and most browsers still\n draw the text in boldface. However, you should not use `&lt;b&gt;` for styling text\n or granting importance. If you wish to create boldface text, you should\n use the CSS `font-weight` property. If you wish to indicate an element is\n of special importance, you should use the `&lt;strong&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/b)\nSynonyms:\nsketch/redraw/dom/html.b\nsketch/redraw/dom/html b","url":"sketch/redraw/dom/html.html#b"},{"doc":"sketch/redraw/dom/html","title":"base","content":"pub fn base(\n  class: Class,\n  attributes: List(Attribute),\n) -&gt; Component\n The `&lt;base&gt;` HTML element specifies the base URL to use for all relative\n URLs in a document. There can be only one `&lt;base&gt;` element in a document.\n\n A document&#39;s used base URL can be accessed by scripts with `Node.baseURI`.\n If the document has no `&lt;base&gt;` elements, then `baseURI` defaults to\n `location.href`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/base)\nSynonyms:\nsketch/redraw/dom/html.base\nsketch/redraw/dom/html base","url":"sketch/redraw/dom/html.html#base"},{"doc":"sketch/redraw/dom/html","title":"bdi","content":"pub fn bdi(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;bdi&gt;` HTML element tells the browser&#39;s bidirectional algorithm to\n treat the text it contains in isolation from its surrounding text. It&#39;s\n particularly useful when a website dynamically inserts some text and\n doesn&#39;t know the directionality of the text being inserted.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/bdi)\nSynonyms:\nsketch/redraw/dom/html.bdi\nsketch/redraw/dom/html bdi","url":"sketch/redraw/dom/html.html#bdi"},{"doc":"sketch/redraw/dom/html","title":"bdo","content":"pub fn bdo(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;bdo&gt;` HTML element overrides the current directionality of text, so\n that the text within is rendered in a different direction.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/bdo)\nSynonyms:\nsketch/redraw/dom/html.bdo\nsketch/redraw/dom/html bdo","url":"sketch/redraw/dom/html.html#bdo"},{"doc":"sketch/redraw/dom/html","title":"blockquote","content":"pub fn blockquote(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;blockquote&gt;` HTML element indicates that the enclosed text is an\n extended quotation. Usually, this is rendered visually by indentation.\n A URL for the source of the quotation may be given using the cite attribute,\n while a text representation of the source can be given using the `&lt;cite&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/blockquote)\nSynonyms:\nsketch/redraw/dom/html.blockquote\nsketch/redraw/dom/html blockquote","url":"sketch/redraw/dom/html.html#blockquote"},{"doc":"sketch/redraw/dom/html","title":"body","content":"pub fn body(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;body&gt;` HTML element represents the content of an HTML document.\n There can be only one `&lt;body&gt;` element in a document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/body)\nSynonyms:\nsketch/redraw/dom/html.body\nsketch/redraw/dom/html body","url":"sketch/redraw/dom/html.html#body"},{"doc":"sketch/redraw/dom/html","title":"br","content":"pub fn br(class: Class, attributes: List(Attribute)) -&gt; Component\n The `&lt;br&gt;` HTML element produces a line break in text (carriage-return).\n It is useful for writing a poem or an address, where the division of\n lines is significant.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/br)\nSynonyms:\nsketch/redraw/dom/html.br\nsketch/redraw/dom/html br","url":"sketch/redraw/dom/html.html#br"},{"doc":"sketch/redraw/dom/html","title":"button","content":"pub fn button(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;button&gt;` HTML element is an interactive element activated by a user\n with a mouse, keyboard, finger, voice command, or other assistive technology.\n Once activated, it then performs an action, such as submitting a form or\n opening a dialog.\n\n By default, HTML buttons are presented in a style resembling the platform\n the user agent runs on, but you can change buttons&#39; appearance with CSS.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/button)\nSynonyms:\nsketch/redraw/dom/html.button\nsketch/redraw/dom/html button","url":"sketch/redraw/dom/html.html#button"},{"doc":"sketch/redraw/dom/html","title":"canvas","content":"pub fn canvas(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n Use the HTML `&lt;canvas&gt;` element with either the\n [canvas scripting API](https://developer.mozilla.org/docs/Web/API/Canvas_API) or the\n [WebGL API](https://developer.mozilla.org/docs/Web/API/WebGL_API)\n to draw graphics and animations.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/canvas)\nSynonyms:\nsketch/redraw/dom/html.canvas\nsketch/redraw/dom/html canvas","url":"sketch/redraw/dom/html.html#canvas"},{"doc":"sketch/redraw/dom/html","title":"caption","content":"pub fn caption(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;caption&gt;` HTML element specifies the caption (or title) of a table, p\n roviding the table an [accessible description](https://developer.mozilla.org/docs/Glossary/Accessible_description).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/caption)\nSynonyms:\nsketch/redraw/dom/html.caption\nsketch/redraw/dom/html caption","url":"sketch/redraw/dom/html.html#caption"},{"doc":"sketch/redraw/dom/html","title":"cite","content":"pub fn cite(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;cite&gt;` HTML element is used to mark up the title of a cited creative\n work. The reference may be in an abbreviated form according to\n context-appropriate conventions related to citation metadata.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/cite)\nSynonyms:\nsketch/redraw/dom/html.cite\nsketch/redraw/dom/html cite","url":"sketch/redraw/dom/html.html#cite"},{"doc":"sketch/redraw/dom/html","title":"code","content":"pub fn code(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;code&gt;` HTML element displays its contents styled in a fashion intended\n to indicate that the text is a short fragment of computer code. By default,\n the content text is displayed using the user agent&#39;s default monospace font.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/code)\nSynonyms:\nsketch/redraw/dom/html.code\nsketch/redraw/dom/html code","url":"sketch/redraw/dom/html.html#code"},{"doc":"sketch/redraw/dom/html","title":"col","content":"pub fn col(\n  class: Class,\n  attributes: List(Attribute),\n) -&gt; Component\n The `&lt;col&gt;` HTML element defines one or more columns in a column group\n represented by its parent `&lt;colgroup&gt;` element. The `&lt;col&gt;` element is\n only valid as a child of a `&lt;colgroup&gt;` element that has no `span`\n attribute defined.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/col)\nSynonyms:\nsketch/redraw/dom/html.col\nsketch/redraw/dom/html col","url":"sketch/redraw/dom/html.html#col"},{"doc":"sketch/redraw/dom/html","title":"colgroup","content":"pub fn colgroup(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;colgroup&gt;` HTML element defines a group of columns within a table.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/colgroup)\nSynonyms:\nsketch/redraw/dom/html.colgroup\nsketch/redraw/dom/html colgroup","url":"sketch/redraw/dom/html.html#colgroup"},{"doc":"sketch/redraw/dom/html","title":"data","content":"pub fn data(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;data&gt;` HTML element links a given piece of content with a\n machine-readable translation. If the content is time- or date-related,\n the `&lt;time&gt;` element must be used.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/data)\nSynonyms:\nsketch/redraw/dom/html.data\nsketch/redraw/dom/html data","url":"sketch/redraw/dom/html.html#data"},{"doc":"sketch/redraw/dom/html","title":"datalist","content":"pub fn datalist(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;datalist&gt;` HTML element contains a set of `&lt;option&gt;` elements that\n represent the permissible or recommended options available to choose from\n within other controls.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/datalist)\nSynonyms:\nsketch/redraw/dom/html.datalist\nsketch/redraw/dom/html datalist","url":"sketch/redraw/dom/html.html#datalist"},{"doc":"sketch/redraw/dom/html","title":"dd","content":"pub fn dd(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;dd&gt;` HTML element provides the description, definition, or value for\n the preceding term (`&lt;dt&gt;`) in a description list (`&lt;dl&gt;`).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dd)\nSynonyms:\nsketch/redraw/dom/html.dd\nsketch/redraw/dom/html dd","url":"sketch/redraw/dom/html.html#dd"},{"doc":"sketch/redraw/dom/html","title":"del","content":"pub fn del(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;del&gt;` HTML element represents a range of text that has been deleted\n from a document. This can be used when rendering &quot;track changes&quot; or source\n code diff information, for example. The `&lt;ins&gt;` element can be used for the\n opposite purpose: to indicate text that has been added to the document.\n\n This element is often (but need not be) rendered by applying a\n strike-through style to the text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/del)\nSynonyms:\nsketch/redraw/dom/html.del\nsketch/redraw/dom/html del","url":"sketch/redraw/dom/html.html#del"},{"doc":"sketch/redraw/dom/html","title":"details","content":"pub fn details(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;details&gt;` HTML element creates a disclosure widget in which\n information is visible only when the widget is toggled into an &quot;open&quot; state.\n A summary or label must be provided using the `&lt;summary&gt;` element.\n\n A disclosure widget is typically presented onscreen using a small triangle\n that rotates (or twists) to indicate open/closed status, with a label next\n to the triangle. The contents of the `&lt;summary&gt;` element are used as the\n label for the disclosure widget. The contents of the `&lt;details&gt;` provide\n the accessible description for the `&lt;summary&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/details)\nSynonyms:\nsketch/redraw/dom/html.details\nsketch/redraw/dom/html details","url":"sketch/redraw/dom/html.html#details"},{"doc":"sketch/redraw/dom/html","title":"dfn","content":"pub fn dfn(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;dfn&gt;` HTML element indicates a term to be defined. The `&lt;dfn&gt;` element\n should be used in a complete definition statement, where the full definition\n of the term can be one of the following:\n - The ancestor paragraph (a block of text, sometimes marked by a `&lt;p&gt;`\n   element)\n - The `&lt;dt&gt;`/`&lt;dd&gt;` pairing\n - The nearest section ancestor of the `&lt;dfn&gt;` element\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dfn)\nSynonyms:\nsketch/redraw/dom/html.dfn\nsketch/redraw/dom/html dfn","url":"sketch/redraw/dom/html.html#dfn"},{"doc":"sketch/redraw/dom/html","title":"dialog","content":"pub fn dialog(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;dialog&gt;` HTML element represents a modal or non-modal dialog box or\n other interactive component, such as a dismissible alert, inspector, or\n subwindow.\n\n The HTML `&lt;dialog&gt;` element is used to create both modal and non-modal\n dialog boxes. Modal dialog boxes interrupt interaction with the rest of the\n page being inert, while non-modal dialog boxes allow interaction with the\n rest of the page.\n\n JavaScript should be used to display the `&lt;dialog&gt;` element. Use the\n `.showModal()` method to display a modal dialog and the `.show()` method\n to display a non-modal dialog. The dialog box can be closed using the\n `.close()` method or using the `dialog` method when submitting a `&lt;form&gt;`\n that is nested within the `&lt;dialog&gt;` element. Modal dialogs can also be\n closed by pressing the Esc key.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dialog)\nSynonyms:\nsketch/redraw/dom/html.dialog\nsketch/redraw/dom/html dialog","url":"sketch/redraw/dom/html.html#dialog"},{"doc":"sketch/redraw/dom/html","title":"div","content":"pub fn div(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;div&gt;` HTML element is the generic container for flow content. It has\n no effect on the content or layout until styled in some way using CSS (e.g.\n styling is directly applied to it, or some kind of layout model like Flexbox\n is applied to its parent element).\n\n As a &quot;pure&quot; container, the `&lt;div&gt;` element does not inherently represent\n anything. Instead, it&#39;s used to group content so it can be easily styled\n using the `class` or `id` attributes, marking a section of a document as\n being written in a different language (using the `lang` attribute),\n and so on.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/div)\nSynonyms:\nsketch/redraw/dom/html.div\nsketch/redraw/dom/html div","url":"sketch/redraw/dom/html.html#div"},{"doc":"sketch/redraw/dom/html","title":"dl","content":"pub fn dl(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;dl&gt;` HTML element represents a description list. The element encloses\n a list of groups of terms (specified using the `&lt;dt&gt;` element) and\n descriptions (provided by `&lt;dd&gt;` elements). Common uses for this element are\n to implement a glossary or to display metadata (a list of key-value pairs).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dl)\nSynonyms:\nsketch/redraw/dom/html.dl\nsketch/redraw/dom/html dl","url":"sketch/redraw/dom/html.html#dl"},{"doc":"sketch/redraw/dom/html","title":"dt","content":"pub fn dt(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;dt&gt;` HTML element specifies a term in a description or definition list,\n and as such must be used inside a `&lt;dl&gt;` element. It is usually followed by\n a `&lt;dd&gt;` element; however, multiple `&lt;dt&gt;` elements in a row indicate several\n terms that are all defined by the immediate next `&lt;dd&gt;` element.\n\n The subsequent `&lt;dd&gt;` (Description Details) element provides the definition\n or other related text associated with the term specified using `&lt;dt&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dt)\nSynonyms:\nsketch/redraw/dom/html.dt\nsketch/redraw/dom/html dt","url":"sketch/redraw/dom/html.html#dt"},{"doc":"sketch/redraw/dom/html","title":"em","content":"pub fn em(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;em&gt;` HTML element marks text that has stress emphasis. The `&lt;em&gt;`\n element can be nested, with each level of nesting indicating a greater\n degree of emphasis.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/em)\nSynonyms:\nsketch/redraw/dom/html.em\nsketch/redraw/dom/html em","url":"sketch/redraw/dom/html.html#em"},{"doc":"sketch/redraw/dom/html","title":"embed","content":"pub fn embed(\n  class: Class,\n  attributes: List(Attribute),\n) -&gt; Component\n The `&lt;embed&gt;` HTML element embeds external content at the specified point in\n the document. This content is provided by an external application or other\n source of interactive content such as a browser plug-in.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/embed)\nSynonyms:\nsketch/redraw/dom/html.embed\nsketch/redraw/dom/html embed","url":"sketch/redraw/dom/html.html#embed"},{"doc":"sketch/redraw/dom/html","title":"fieldset","content":"pub fn fieldset(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;fieldset&gt;` HTML element is used to group several controls as well as\n labels (`&lt;label&gt;`) within a web form.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/fieldset)\nSynonyms:\nsketch/redraw/dom/html.fieldset\nsketch/redraw/dom/html fieldset","url":"sketch/redraw/dom/html.html#fieldset"},{"doc":"sketch/redraw/dom/html","title":"figcaption","content":"pub fn figcaption(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;figcaption&gt;` HTML element represents a caption or legend describing\n the rest of the contents of its parent `&lt;figure&gt;` element, providing the\n `&lt;figure&gt;` an [accessible description](https://developer.mozilla.org/docs/Glossary/Accessible_description).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/figcaption)\nSynonyms:\nsketch/redraw/dom/html.figcaption\nsketch/redraw/dom/html figcaption","url":"sketch/redraw/dom/html.html#figcaption"},{"doc":"sketch/redraw/dom/html","title":"figure","content":"pub fn figure(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;figure&gt;` HTML element represents self-contained content, potentially\n with an optional caption, which is specified using the `&lt;figcaption&gt;`\n element. The figure, its caption, and its contents are referenced as a\n single unit.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/figure)\nSynonyms:\nsketch/redraw/dom/html.figure\nsketch/redraw/dom/html figure","url":"sketch/redraw/dom/html.html#figure"},{"doc":"sketch/redraw/dom/html","title":"footer","content":"pub fn footer(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;footer&gt;` HTML element represents a footer for its nearest ancestor\n [sectioning content](https://developer.mozilla.org/docs/Web/HTML/Content_categories#sectioning_content)\n or [sectioning root](https://developer.mozilla.org/docs/Web/HTML/Element/Heading_Elements#labeling_section_content)\n element. A `&lt;footer&gt;` typically contains information about the author of\n the section, copyright data or links to related documents.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/footer)\nSynonyms:\nsketch/redraw/dom/html.footer\nsketch/redraw/dom/html footer","url":"sketch/redraw/dom/html.html#footer"},{"doc":"sketch/redraw/dom/html","title":"form","content":"pub fn form(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;form&gt;` HTML element represents a document section containing\n interactive controls for submitting information.\n\n It is possible to use the `:valid` and `:invalid` CSS pseudo-classes to\n style a `&lt;form&gt;` element based on whether the elements inside the form\n are valid.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/form)\nSynonyms:\nsketch/redraw/dom/html.form\nsketch/redraw/dom/html form","url":"sketch/redraw/dom/html.html#form"},{"doc":"sketch/redraw/dom/html","title":"h1","content":"pub fn h1(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h1)\nSynonyms:\nsketch/redraw/dom/html.h1\nsketch/redraw/dom/html h1","url":"sketch/redraw/dom/html.html#h1"},{"doc":"sketch/redraw/dom/html","title":"h2","content":"pub fn h2(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h2)\nSynonyms:\nsketch/redraw/dom/html.h2\nsketch/redraw/dom/html h2","url":"sketch/redraw/dom/html.html#h2"},{"doc":"sketch/redraw/dom/html","title":"h3","content":"pub fn h3(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h3)\nSynonyms:\nsketch/redraw/dom/html.h3\nsketch/redraw/dom/html h3","url":"sketch/redraw/dom/html.html#h3"},{"doc":"sketch/redraw/dom/html","title":"h4","content":"pub fn h4(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h4)\nSynonyms:\nsketch/redraw/dom/html.h4\nsketch/redraw/dom/html h4","url":"sketch/redraw/dom/html.html#h4"},{"doc":"sketch/redraw/dom/html","title":"h5","content":"pub fn h5(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h5)\nSynonyms:\nsketch/redraw/dom/html.h5\nsketch/redraw/dom/html h5","url":"sketch/redraw/dom/html.html#h5"},{"doc":"sketch/redraw/dom/html","title":"h6","content":"pub fn h6(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h6)\nSynonyms:\nsketch/redraw/dom/html.h6\nsketch/redraw/dom/html h6","url":"sketch/redraw/dom/html.html#h6"},{"doc":"sketch/redraw/dom/html","title":"head","content":"pub fn head(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;head&gt;` HTML element contains machine-readable information (metadata)\n about the document, like its title, scripts, and style sheets. There can be\n only one `&lt;head&gt;` element in an HTML document.\n\n &gt; `&lt;head&gt;` primarily holds information for machine processing, not\n &gt; human-readability. For human-visible information, like top-level headings\n &gt; and listed authors, see the `&lt;header&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/head)\nSynonyms:\nsketch/redraw/dom/html.head\nsketch/redraw/dom/html head","url":"sketch/redraw/dom/html.html#head"},{"doc":"sketch/redraw/dom/html","title":"header","content":"pub fn header(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;header&gt;` HTML element represents introductory content, typically a\n group of introductory or navigational aids. It may contain some heading\n elements but also a logo, a search form, an author name, and other elements.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/header)\nSynonyms:\nsketch/redraw/dom/html.header\nsketch/redraw/dom/html header","url":"sketch/redraw/dom/html.html#header"},{"doc":"sketch/redraw/dom/html","title":"hgroup","content":"pub fn hgroup(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;hgroup&gt;` HTML element represents a heading and related content. It\n groups a single `&lt;h1&gt;`–`&lt;h6&gt;` element with one or more `&lt;p&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/hgroup)\nSynonyms:\nsketch/redraw/dom/html.hgroup\nsketch/redraw/dom/html hgroup","url":"sketch/redraw/dom/html.html#hgroup"},{"doc":"sketch/redraw/dom/html","title":"hr","content":"pub fn hr(class: Class, attributes: List(Attribute)) -&gt; Component\n The `&lt;hr&gt;` HTML element represents a thematic break between paragraph-level\n elements: for example, a change of scene in a story, or a shift of topic\n within a section.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/hr)\nSynonyms:\nsketch/redraw/dom/html.hr\nsketch/redraw/dom/html hr","url":"sketch/redraw/dom/html.html#hr"},{"doc":"sketch/redraw/dom/html","title":"html","content":"pub fn html(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;html&gt;` HTML element represents the root (top-level element) of an\n HTML document, so it is also referred to as the root element. All other\n elements must be descendants of this element. There can be only one `&lt;html&gt;`\n element in a document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/html)\nSynonyms:\nsketch/redraw/dom/html.html\nsketch/redraw/dom/html html","url":"sketch/redraw/dom/html.html#html"},{"doc":"sketch/redraw/dom/html","title":"i","content":"pub fn i(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;i&gt;` HTML element represents a range of text that is set off from the\n normal text for some reason, such as idiomatic text, technical terms,\n taxonomical designations, among others. Historically, these have been\n presented using italicized type, which is the original source of the `&lt;i&gt;`\n naming of this element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/i)\nSynonyms:\nsketch/redraw/dom/html.i\nsketch/redraw/dom/html i","url":"sketch/redraw/dom/html.html#i"},{"doc":"sketch/redraw/dom/html","title":"iframe","content":"pub fn iframe(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;iframe&gt;` HTML element represents a nested browsing context, embedding\n another HTML page into the current one.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/iframe)\nSynonyms:\nsketch/redraw/dom/html.iframe\nsketch/redraw/dom/html iframe","url":"sketch/redraw/dom/html.html#iframe"},{"doc":"sketch/redraw/dom/html","title":"img","content":"pub fn img(\n  class: Class,\n  attributes: List(Attribute),\n) -&gt; Component\n The `&lt;img&gt;` HTML element embeds an image into the document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/img)\nSynonyms:\nsketch/redraw/dom/html.img\nsketch/redraw/dom/html img","url":"sketch/redraw/dom/html.html#img"},{"doc":"sketch/redraw/dom/html","title":"input","content":"pub fn input(\n  class: Class,\n  attributes: List(Attribute),\n) -&gt; Component\n The `&lt;input&gt;` HTML element is used to create interactive controls for\n web-based forms in order to accept data from the user; a wide variety of\n types of input data and control widgets are available, depending on the\n device and user agent. The `&lt;input&gt;` element is one of the most powerful and\n complex in all of HTML due to the sheer number of combinations of input\n types and attributes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/input)\nSynonyms:\nsketch/redraw/dom/html.input\nsketch/redraw/dom/html input","url":"sketch/redraw/dom/html.html#input"},{"doc":"sketch/redraw/dom/html","title":"ins","content":"pub fn ins(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;ins&gt;` HTML element represents a range of text that has been added to\n a document. You can use the `&lt;del&gt;` element to similarly represent a range\n of text that has been deleted from the document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ins)\nSynonyms:\nsketch/redraw/dom/html.ins\nsketch/redraw/dom/html ins","url":"sketch/redraw/dom/html.html#ins"},{"doc":"sketch/redraw/dom/html","title":"kbd","content":"pub fn kbd(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;kbd&gt;` HTML element represents a span of inline text denoting textual\n user input from a keyboard, voice input, or any other text entry device. By\n convention, the user agent defaults to rendering the contents of a `&lt;kbd&gt;`\n element using its default monospace font, although this is not mandated by\n the HTML standard.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/kbd)\nSynonyms:\nsketch/redraw/dom/html.kbd\nsketch/redraw/dom/html kbd","url":"sketch/redraw/dom/html.html#kbd"},{"doc":"sketch/redraw/dom/html","title":"label","content":"pub fn label(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;label&gt;` HTML element represents a caption for an item in a user\n interface.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/label)\nSynonyms:\nsketch/redraw/dom/html.label\nsketch/redraw/dom/html label","url":"sketch/redraw/dom/html.html#label"},{"doc":"sketch/redraw/dom/html","title":"legend","content":"pub fn legend(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;legend&gt;` HTML element represents a caption for the content of\n its parent `&lt;fieldset&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/legend)\nSynonyms:\nsketch/redraw/dom/html.legend\nsketch/redraw/dom/html legend","url":"sketch/redraw/dom/html.html#legend"},{"doc":"sketch/redraw/dom/html","title":"li","content":"pub fn li(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;li&gt;` HTML element is used to represent an item in a list. It must be\n contained in a parent element: an ordered list (`&lt;ol&gt;`), an unordered list\n (`&lt;ul&gt;`), or a menu (`&lt;menu&gt;`). In menus and unordered lists, list items are\n usually displayed using bullet points. In ordered lists, they are usually\n displayed with an ascending counter on the left, such as a number or letter.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/li)\nSynonyms:\nsketch/redraw/dom/html.li\nsketch/redraw/dom/html li","url":"sketch/redraw/dom/html.html#li"},{"doc":"sketch/redraw/dom/html","title":"link","content":"pub fn link(\n  class: Class,\n  attributes: List(Attribute),\n) -&gt; Component\n The `&lt;link&gt;` HTML element specifies relationships between the current\n document and an external resource. This element is most commonly used to\n link to stylesheets, but is also used to establish site icons (both &quot;favicon&quot;\n style icons and icons for the home screen and apps on mobile devices) among\n other things.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/link)\nSynonyms:\nsketch/redraw/dom/html.link\nsketch/redraw/dom/html link","url":"sketch/redraw/dom/html.html#link"},{"doc":"sketch/redraw/dom/html","title":"main","content":"pub fn main(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;main&gt;` HTML element represents the dominant content of the `&lt;body&gt;` of\n a document. The main content area consists of content that is directly\n related to or expands upon the central topic of a document, or the central\n functionality of an application.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/main)\nSynonyms:\nsketch/redraw/dom/html.main\nsketch/redraw/dom/html main","url":"sketch/redraw/dom/html.html#main"},{"doc":"sketch/redraw/dom/html","title":"map","content":"pub fn map(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;map&gt;` HTML element is used with `&lt;area&gt;` elements to define an\n image map (a clickable link area).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/map)\nSynonyms:\nsketch/redraw/dom/html.map\nsketch/redraw/dom/html map","url":"sketch/redraw/dom/html.html#map"},{"doc":"sketch/redraw/dom/html","title":"mark","content":"pub fn mark(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;mark&gt;` HTML element represents text which is marked or highlighted for\n reference or notation purposes due to the marked passage&#39;s relevance in the\n enclosing context.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/mark)\nSynonyms:\nsketch/redraw/dom/html.mark\nsketch/redraw/dom/html mark","url":"sketch/redraw/dom/html.html#mark"},{"doc":"sketch/redraw/dom/html","title":"math","content":"pub fn math(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;math&gt;` MathML element is the top-level MathML element, used to write\n a single mathematical formula. It can be placed in HTML content where flow\n content is permitted.\n\n &gt; See the [Authoring MathML page](https://developer.mozilla.org/docs/Web/MathML/Authoring#using_mathml)\n &gt; for tips to properly integrate MathML formulas in your web pages and the\n &gt; [Examples](https://developer.mozilla.org/docs/Web/MathML/Examples)\n &gt; page for more demos.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/MathML/Element/math)\nSynonyms:\nsketch/redraw/dom/html.math\nsketch/redraw/dom/html math","url":"sketch/redraw/dom/html.html#math"},{"doc":"sketch/redraw/dom/html","title":"menu","content":"pub fn menu(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;menu&gt;` HTML element is described in the HTML specification as a\n semantic alternative to `&lt;ul&gt;`, but treated by browsers (and exposed through\n the accessibility tree) as no different than `&lt;ul&gt;`. It represents an\n unordered list of items (which are represented by `&lt;li&gt;` elements).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/menu)\nSynonyms:\nsketch/redraw/dom/html.menu\nsketch/redraw/dom/html menu","url":"sketch/redraw/dom/html.html#menu"},{"doc":"sketch/redraw/dom/html","title":"meta","content":"pub fn meta(\n  class: Class,\n  attributes: List(Attribute),\n) -&gt; Component\n The `&lt;meta&gt;` HTML element represents metadata that cannot be represented\n by other HTML meta-related elements, like `&lt;base&gt;`, `&lt;link&gt;`, `&lt;script&gt;`,\n `&lt;style&gt;` or `&lt;title&gt;`.\n\n The type of metadata provided by the `&lt;meta&gt;` element can be one of the\n following:\n - If the `name` attribute is set, the `&lt;meta&gt;` element provides\n   document-level metadata, applying to the whole page.\n - If the `http-equiv` attribute is set, the `&lt;meta&gt;` element is a pragma\n   directive, providing information equivalent to what can be given by a\n   similarly-named HTTP header.\n - If the `charset` attribute is set, the `&lt;meta&gt;` element is a charset\n   declaration, giving the character encoding in which the document is encoded.\n - If the `itemprop` attribute is set, the `&lt;meta&gt;` element provides\n   user-defined metadata.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/meta)\nSynonyms:\nsketch/redraw/dom/html.meta\nsketch/redraw/dom/html meta","url":"sketch/redraw/dom/html.html#meta"},{"doc":"sketch/redraw/dom/html","title":"meter","content":"pub fn meter(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;meter&gt;` HTML element represents either a scalar value within a\n known range or a fractional value.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/meter)\nSynonyms:\nsketch/redraw/dom/html.meter\nsketch/redraw/dom/html meter","url":"sketch/redraw/dom/html.html#meter"},{"doc":"sketch/redraw/dom/html","title":"nav","content":"pub fn nav(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;nav&gt;` HTML element represents a section of a page whose purpose is to\n provide navigation links, either within the current document or to other\n documents. Common examples of navigation sections are menus, tables of\n contents, and indexes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/nav)\nSynonyms:\nsketch/redraw/dom/html.nav\nsketch/redraw/dom/html nav","url":"sketch/redraw/dom/html.html#nav"},{"doc":"sketch/redraw/dom/html","title":"noscript","content":"pub fn noscript(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;noscript&gt;` HTML element defines a section of HTML to be inserted if a\n script type on the page is unsupported or if scripting is currently turned\n off in the browser.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/noscript)\nSynonyms:\nsketch/redraw/dom/html.noscript\nsketch/redraw/dom/html noscript","url":"sketch/redraw/dom/html.html#noscript"},{"doc":"sketch/redraw/dom/html","title":"object","content":"pub fn object(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;object&gt;` HTML element represents an external resource, which can be\n treated as an image, a nested browsing context, or a resource to be handled\n by a plugin.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/object)\nSynonyms:\nsketch/redraw/dom/html.object\nsketch/redraw/dom/html object","url":"sketch/redraw/dom/html.html#object"},{"doc":"sketch/redraw/dom/html","title":"ol","content":"pub fn ol(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;ol&gt;` HTML element represents an ordered list of items — typically\n rendered as a numbered list.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ol)\nSynonyms:\nsketch/redraw/dom/html.ol\nsketch/redraw/dom/html ol","url":"sketch/redraw/dom/html.html#ol"},{"doc":"sketch/redraw/dom/html","title":"optgroup","content":"pub fn optgroup(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;optgroup&gt;` HTML element creates a grouping of options within a\n `&lt;select&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/optgroup)\nSynonyms:\nsketch/redraw/dom/html.optgroup\nsketch/redraw/dom/html optgroup","url":"sketch/redraw/dom/html.html#optgroup"},{"doc":"sketch/redraw/dom/html","title":"option","content":"pub fn option(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;option&gt;` HTML element is used to define an item contained in a\n `&lt;select&gt;`, an `&lt;optgroup&gt;`, or a `&lt;datalist&gt;` element. As such, `&lt;option&gt;`\n can represent menu items in popups and other lists of items in an HTML\n document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/option)\nSynonyms:\nsketch/redraw/dom/html.option\nsketch/redraw/dom/html option","url":"sketch/redraw/dom/html.html#option"},{"doc":"sketch/redraw/dom/html","title":"output","content":"pub fn output(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;output&gt;` HTML element is a container element into which a site or\n app can inject the results of a calculation or the outcome of a user action.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/output)\nSynonyms:\nsketch/redraw/dom/html.output\nsketch/redraw/dom/html output","url":"sketch/redraw/dom/html.html#output"},{"doc":"sketch/redraw/dom/html","title":"p","content":"pub fn p(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;p&gt;` HTML element represents a paragraph. Paragraphs are usually\n represented in visual media as blocks of text separated from adjacent\n blocks by blank lines and/or first-line indentation, but HTML paragraphs\n can be any structural grouping of related content, such as images or form\n fields.\n\n Paragraphs are block-level elements, and notably will automatically close\n if another block-level element is parsed before the closing `&lt;/p&gt;` tag.\n See &quot;Tag omission&quot; below.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/p)\nSynonyms:\nsketch/redraw/dom/html.p\nsketch/redraw/dom/html p","url":"sketch/redraw/dom/html.html#p"},{"doc":"sketch/redraw/dom/html","title":"picture","content":"pub fn picture(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;picture&gt;` HTML element contains zero or more `&lt;source&gt;` elements and\n one `&lt;img&gt;` element to offer alternative versions of an image for different\n display/device scenarios.\n\n The browser will consider each child `&lt;source&gt;` element and choose the best\n match among them. If no matches are found—or the browser doesn&#39;t support\n the `&lt;picture&gt;` element—the URL of the `&lt;img&gt;` element&#39;s `src` attribute is\n selected. The selected image is then presented in the space occupied by\n the `&lt;img&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/picture)\nSynonyms:\nsketch/redraw/dom/html.picture\nsketch/redraw/dom/html picture","url":"sketch/redraw/dom/html.html#picture"},{"doc":"sketch/redraw/dom/html","title":"portal","content":"pub fn portal(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;portal&gt;` HTML element enables the embedding of another HTML page into\n the current one for the purposes of allowing smoother navigation into new pages.\n\n A `&lt;portal&gt;` is similar to an `&lt;iframe&gt;`. An `&lt;iframe&gt;` allows a separate\n browsing context to be embedded. However, the embedded content of a\n `&lt;portal&gt;` is more limited than that of an `&lt;iframe&gt;`. It cannot be\n interacted with, and therefore is not suitable for embedding widgets into a\n document. Instead, the &lt;portal&gt; acts as a preview of the content of another\n page. It can be navigated into therefore allowing for seamless transition\n to the embedded content.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/portal)\nSynonyms:\nsketch/redraw/dom/html.portal\nsketch/redraw/dom/html portal","url":"sketch/redraw/dom/html.html#portal"},{"doc":"sketch/redraw/dom/html","title":"pre","content":"pub fn pre(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;pre&gt;` HTML element represents preformatted text which is to be\n presented exactly as written in the HTML file. The text is typically\n rendered using a non-proportional, or monospaced, font. Whitespace inside\n this element is displayed as written.\n\n By default, `&lt;pre&gt;` is a block-level element, i.e. its default `display`\n value is `block`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/pre)\nSynonyms:\nsketch/redraw/dom/html.pre\nsketch/redraw/dom/html pre","url":"sketch/redraw/dom/html.html#pre"},{"doc":"sketch/redraw/dom/html","title":"progress","content":"pub fn progress(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;progress&gt;` HTML element displays an indicator showing the completion\n progress of a task, typically displayed as a progress bar.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/progress)\nSynonyms:\nsketch/redraw/dom/html.progress\nsketch/redraw/dom/html progress","url":"sketch/redraw/dom/html.html#progress"},{"doc":"sketch/redraw/dom/html","title":"q","content":"pub fn q(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;q&gt;` HTML element indicates that the enclosed text is a short inline\n quotation. Most modern browsers implement this by surrounding the text in\n quotation marks. This element is intended for short quotations that don&#39;t\n require paragraph breaks; for long quotations use the `&lt;blockquote&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/q)\nSynonyms:\nsketch/redraw/dom/html.q\nsketch/redraw/dom/html q","url":"sketch/redraw/dom/html.html#q"},{"doc":"sketch/redraw/dom/html","title":"rp","content":"pub fn rp(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;rp&gt;` HTML element is used to provide fall-back parentheses for\n browsers that do not support display of ruby annotations using the `&lt;ruby&gt;`\n element. One `&lt;rp&gt;` element should enclose each of the opening and closing\n parentheses that wrap the `&lt;rt&gt;` element that contains the annotation&#39;s text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/rp)\nSynonyms:\nsketch/redraw/dom/html.rp\nsketch/redraw/dom/html rp","url":"sketch/redraw/dom/html.html#rp"},{"doc":"sketch/redraw/dom/html","title":"rt","content":"pub fn rt(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;rt&gt;` HTML element specifies the ruby text component of a ruby\n annotation, which is used to provide pronunciation, translation, or\n transliteration information for East Asian typography. The `&lt;rt&gt;` element\n must always be contained within a `&lt;ruby&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/rt)\nSynonyms:\nsketch/redraw/dom/html.rt\nsketch/redraw/dom/html rt","url":"sketch/redraw/dom/html.html#rt"},{"doc":"sketch/redraw/dom/html","title":"ruby","content":"pub fn ruby(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;ruby&gt;` HTML element represents small annotations that are rendered\n above, below, or next to base text, usually used for showing the\n pronunciation of East Asian characters. It can also be used for annotating\n other kinds of text, but this usage is less common.\n\n The term ruby originated as a\n [unit of measurement used by typesetters](https://en.wikipedia.org/wiki/Agate_(typography)),\n representing the smallest size that text can be printed on newsprint while\n remaining legible.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ruby)\nSynonyms:\nsketch/redraw/dom/html.ruby\nsketch/redraw/dom/html ruby","url":"sketch/redraw/dom/html.html#ruby"},{"doc":"sketch/redraw/dom/html","title":"s","content":"pub fn s(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;s&gt;` HTML element renders text with a strikethrough, or a line through\n it. Use the `&lt;s&gt;` element to represent things that are no longer relevant or\n no longer accurate. However, `&lt;s&gt;` is not appropriate when indicating\n document edits; for that, use the `&lt;del&gt;` and `&lt;ins&gt;` elements, as\n appropriate.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/s)\nSynonyms:\nsketch/redraw/dom/html.s\nsketch/redraw/dom/html s","url":"sketch/redraw/dom/html.html#s"},{"doc":"sketch/redraw/dom/html","title":"samp","content":"pub fn samp(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;samp&gt;` HTML element is used to enclose inline text which represents\n sample (or quoted) output from a computer program. Its contents are\n typically rendered using the browser&#39;s default monospaced font (such as\n Courier or Lucida Console).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/samp)\nSynonyms:\nsketch/redraw/dom/html.samp\nsketch/redraw/dom/html samp","url":"sketch/redraw/dom/html.html#samp"},{"doc":"sketch/redraw/dom/html","title":"script","content":"pub fn script(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;script&gt;` HTML element is used to embed executable code or data; this\n is typically used to embed or refer to JavaScript code. The `&lt;script&gt;`\n element can also be used with other languages, such as WebGL&#39;s GLSL shader\n programming language and JSON.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/script)\nSynonyms:\nsketch/redraw/dom/html.script\nsketch/redraw/dom/html script","url":"sketch/redraw/dom/html.html#script"},{"doc":"sketch/redraw/dom/html","title":"search","content":"pub fn search(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;search&gt;` HTML element is a container representing the parts of the\n document or application with form controls or other content related to\n performing a search or filtering operation. The &lt;search&gt; element\n semantically identifies the purpose of the element&#39;s contents as having\n search or filtering capabilities. The search or filtering functionality can\n be for the website or application, the current web page or document, or the\n entire Internet or subsection thereof.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/search)\nSynonyms:\nsketch/redraw/dom/html.search\nsketch/redraw/dom/html search","url":"sketch/redraw/dom/html.html#search"},{"doc":"sketch/redraw/dom/html","title":"section","content":"pub fn section(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;section&gt;` HTML element represents a generic standalone section of a\n document, which doesn&#39;t have a more specific semantic element to represent\n it. Sections should always have a heading, with very few exceptions.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/section)\nSynonyms:\nsketch/redraw/dom/html.section\nsketch/redraw/dom/html section","url":"sketch/redraw/dom/html.html#section"},{"doc":"sketch/redraw/dom/html","title":"select","content":"pub fn select(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;select&gt;` HTML element represents a control that provides a menu of options.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/select)\nSynonyms:\nsketch/redraw/dom/html.select\nsketch/redraw/dom/html select","url":"sketch/redraw/dom/html.html#select"},{"doc":"sketch/redraw/dom/html","title":"slot","content":"pub fn slot(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;slot&gt;` HTML element—part of the Web Components technology suite—is a\n placeholder inside a web component that you can fill with your own markup,\n which lets you create separate DOM trees and present them together.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/slot)\nSynonyms:\nsketch/redraw/dom/html.slot\nsketch/redraw/dom/html slot","url":"sketch/redraw/dom/html.html#slot"},{"doc":"sketch/redraw/dom/html","title":"small","content":"pub fn small(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;small&gt;` HTML element represents side-comments and small print, like\n `copyright and legal text, independent of its styled presentation. By\n default, it renders text within it one font-size smaller, such as from\n `small` to `x-small`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/small)\nSynonyms:\nsketch/redraw/dom/html.small\nsketch/redraw/dom/html small","url":"sketch/redraw/dom/html.html#small"},{"doc":"sketch/redraw/dom/html","title":"source","content":"pub fn source(\n  class: Class,\n  attributes: List(Attribute),\n) -&gt; Component\n The `&lt;source&gt;` HTML element specifies one or more media resources for the\n `&lt;picture&gt;,` `&lt;audio&gt;,` and `&lt;video&gt;` elements. It is a\n [void element](https://developer.mozilla.org/docs/Glossary/Void_element),\n which means that it has no content and does not require a closing tag. This\n element is commonly used to offer the same media content in multiple file\n formats in order to provide compatibility with a broad range of browsers\n given their differing support for image file formats and media file formats.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/source)\nSynonyms:\nsketch/redraw/dom/html.source\nsketch/redraw/dom/html source","url":"sketch/redraw/dom/html.html#source"},{"doc":"sketch/redraw/dom/html","title":"span","content":"pub fn span(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;span&gt;` HTML element is a generic inline container for phrasing content,\n which does not inherently represent anything. It can be used to group\n elements for styling purposes (using the class or id attributes), or because\n they share attribute values, such as lang. It should be used only when no\n other semantic element is appropriate. `&lt;span&gt;` is very much like a `&lt;div&gt;`\n element, but `&lt;div&gt;` is a block-level element whereas a `&lt;span&gt;` is an\n inline-level element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/span)\nSynonyms:\nsketch/redraw/dom/html.span\nsketch/redraw/dom/html span","url":"sketch/redraw/dom/html.html#span"},{"doc":"sketch/redraw/dom/html","title":"strong","content":"pub fn strong(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;strong&gt;` HTML element indicates that its contents have strong\n importance, seriousness, or urgency. Browsers typically render the\n contents in bold type.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/strong)\nSynonyms:\nsketch/redraw/dom/html.strong\nsketch/redraw/dom/html strong","url":"sketch/redraw/dom/html.html#strong"},{"doc":"sketch/redraw/dom/html","title":"style","content":"pub fn style(\n  class: Class,\n  attributes: List(Attribute),\n  child: String,\n) -&gt; Component\n The `&lt;style&gt;` HTML element contains style information for a document, or\n part of a document. It contains CSS, which is applied to the contents of\n the document containing the `&lt;style&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/style)\nSynonyms:\nsketch/redraw/dom/html.style\nsketch/redraw/dom/html style","url":"sketch/redraw/dom/html.html#style"},{"doc":"sketch/redraw/dom/html","title":"sub","content":"pub fn sub(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;sub&gt;` HTML element specifies inline text which should be displayed as\n subscript for solely typographical reasons. Subscripts are typically\n rendered with a lowered baseline using smaller text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/sub)\nSynonyms:\nsketch/redraw/dom/html.sub\nsketch/redraw/dom/html sub","url":"sketch/redraw/dom/html.html#sub"},{"doc":"sketch/redraw/dom/html","title":"summary","content":"pub fn summary(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;summary&gt;` HTML element specifies a summary, caption, or legend for a\n `&lt;details&gt;` element&#39;s disclosure box. Clicking the `&lt;summary&gt;` element\n toggles the state of the parent `&lt;details&gt;` element open and closed.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/summary)\nSynonyms:\nsketch/redraw/dom/html.summary\nsketch/redraw/dom/html summary","url":"sketch/redraw/dom/html.html#summary"},{"doc":"sketch/redraw/dom/html","title":"sup","content":"pub fn sup(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;sup&gt;` HTML element specifies inline text which is to be displayed as\n superscript for solely typographical reasons. Superscripts are usually\n rendered with a raised baseline using smaller text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/sup)\nSynonyms:\nsketch/redraw/dom/html.sup\nsketch/redraw/dom/html sup","url":"sketch/redraw/dom/html.html#sup"},{"doc":"sketch/redraw/dom/html","title":"table","content":"pub fn table(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;table&gt;` HTML element represents tabular data—that is, information\n presented in a two-dimensional table comprised of rows and columns of\n cells containing data.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/table)\nSynonyms:\nsketch/redraw/dom/html.table\nsketch/redraw/dom/html table","url":"sketch/redraw/dom/html.html#table"},{"doc":"sketch/redraw/dom/html","title":"tbody","content":"pub fn tbody(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;tbody&gt;` HTML element encapsulates a set of table rows (`&lt;tr&gt;`\n elements), indicating that they comprise the body of a table&#39;s (main) data.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/tbody)\nSynonyms:\nsketch/redraw/dom/html.tbody\nsketch/redraw/dom/html tbody","url":"sketch/redraw/dom/html.html#tbody"},{"doc":"sketch/redraw/dom/html","title":"td","content":"pub fn td(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;td&gt;` HTML element defines a cell of a table that contains data and\n may be used as a child of the `&lt;tr&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/td)\nSynonyms:\nsketch/redraw/dom/html.td\nsketch/redraw/dom/html td","url":"sketch/redraw/dom/html.html#td"},{"doc":"sketch/redraw/dom/html","title":"template","content":"pub fn template(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;template&gt;` HTML element serves as a mechanism for holding HTML\n fragments, which can either be used later via JavaScript or generated\n immediately into shadow DOM.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/template)\nSynonyms:\nsketch/redraw/dom/html.template\nsketch/redraw/dom/html template","url":"sketch/redraw/dom/html.html#template"},{"doc":"sketch/redraw/dom/html","title":"text","content":"pub fn text(content: String) -&gt; Component\n The `Text` interface represents a text node in a DOM tree.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/API/Text)\nSynonyms:\nsketch/redraw/dom/html.text\nsketch/redraw/dom/html text","url":"sketch/redraw/dom/html.html#text"},{"doc":"sketch/redraw/dom/html","title":"textarea","content":"pub fn textarea(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;textarea&gt;` HTML element represents a multi-line plain-text editing\n control, useful when you want to allow users to enter a sizeable amount of\n free-form text, for example a comment on a review or feedback form.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/textarea)\nSynonyms:\nsketch/redraw/dom/html.textarea\nsketch/redraw/dom/html textarea","url":"sketch/redraw/dom/html.html#textarea"},{"doc":"sketch/redraw/dom/html","title":"tfoot","content":"pub fn tfoot(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;tfoot&gt;` HTML element encapsulates a set of table rows (`&lt;tr&gt;`\n elements), indicating that they comprise the foot of a table with\n information about the table&#39;s columns. This is usually a summary of the\n columns, e.g., a sum of the given numbers in a column.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/tfoot)\nSynonyms:\nsketch/redraw/dom/html.tfoot\nsketch/redraw/dom/html tfoot","url":"sketch/redraw/dom/html.html#tfoot"},{"doc":"sketch/redraw/dom/html","title":"th","content":"pub fn th(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;th&gt;` HTML element defines a cell as the header of a group of table\n cells and may be used as a child of the `&lt;tr&gt;` element. The exact nature\n of this group is defined by the `scope` and `headers` attributes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/th)\nSynonyms:\nsketch/redraw/dom/html.th\nsketch/redraw/dom/html th","url":"sketch/redraw/dom/html.html#th"},{"doc":"sketch/redraw/dom/html","title":"thead","content":"pub fn thead(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;thead&gt;` HTML element encapsulates a set of table rows (`&lt;tr&gt;`\n elements), indicating that they comprise the head of a table with\n information about the table&#39;s columns. This is usually in the form of\n column headers (`&lt;th&gt;` elements).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/thead)\nSynonyms:\nsketch/redraw/dom/html.thead\nsketch/redraw/dom/html thead","url":"sketch/redraw/dom/html.html#thead"},{"doc":"sketch/redraw/dom/html","title":"time","content":"pub fn time(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;time&gt;` HTML element represents a specific period in time. It may\n include the datetime attribute to translate dates into machine-readable\n format, allowing for better search engine results or custom features such\n as reminders.\n\n It may represent one of the following:\n - A time on a 24-hour clock.\n - A precise date in the [Gregorian calendar](https://en.wikipedia.org/wiki/Gregorian_calendar)\n   (with optional time and timezone information).\n - [A valid time duration](https://html.spec.whatwg.org/multipage/common-microsyntaxes.html#valid-duration-string).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/time)\nSynonyms:\nsketch/redraw/dom/html.time\nsketch/redraw/dom/html time","url":"sketch/redraw/dom/html.html#time"},{"doc":"sketch/redraw/dom/html","title":"title","content":"pub fn title(\n  class: Class,\n  attributes: List(Attribute),\n  title: String,\n) -&gt; Component\n The `&lt;title&gt;` HTML element defines the document&#39;s title that is shown in a\n browser&#39;s title bar or a page&#39;s tab. It only contains text; tags within\n the element are ignored.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/title)\nSynonyms:\nsketch/redraw/dom/html.title\nsketch/redraw/dom/html title","url":"sketch/redraw/dom/html.html#title"},{"doc":"sketch/redraw/dom/html","title":"tr","content":"pub fn tr(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;tr&gt;` HTML element defines a row of cells in a table. The row&#39;s cells\n can then be established using a mix of `&lt;td&gt;` (data cell) and `&lt;th&gt;`\n (header cell) elements.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/tr)\nSynonyms:\nsketch/redraw/dom/html.tr\nsketch/redraw/dom/html tr","url":"sketch/redraw/dom/html.html#tr"},{"doc":"sketch/redraw/dom/html","title":"track","content":"pub fn track(\n  class: Class,\n  attributes: List(Attribute),\n) -&gt; Component\n The `&lt;track&gt;` HTML element is used as a child of the media elements,\n `&lt;audio&gt;` and `&lt;video&gt;`. Each track element lets you specify a timed text\n track (or time-based data) that can be displayed in parallel with the media\n element, for example to overlay subtitles or closed captions on top of a\n video or alongside audio tracks.\n\n Multiple tracks can be specified for a media element, containing different\n kinds of timed text data, or timed text data that has been translated for\n different locales. The data that is used will either be the track that has\n been set to be the default, or a kind and translation based on user\n preferences.\n\n The tracks are formatted in [WebVTT format](https://developer.mozilla.org/docs/Web/API/WebVTT_API)\n (`.vtt` files) — Web Video Text Tracks.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/track)\nSynonyms:\nsketch/redraw/dom/html.track\nsketch/redraw/dom/html track","url":"sketch/redraw/dom/html.html#track"},{"doc":"sketch/redraw/dom/html","title":"u","content":"pub fn u(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;u&gt;` HTML element represents a span of inline text which should be\n rendered in a way that indicates that it has a non-textual annotation. This\n is rendered by default as a single solid underline, but may be altered\n using CSS.\n\n &gt; This element used to be called the &quot;Underline&quot; element in older versions\n &gt; of HTML, and is still sometimes misused in this way. To underline text,\n &gt; you should instead apply a style that includes the CSS `text-decoration`\n &gt; property set to `underline`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/u)\nSynonyms:\nsketch/redraw/dom/html.u\nsketch/redraw/dom/html u","url":"sketch/redraw/dom/html.html#u"},{"doc":"sketch/redraw/dom/html","title":"ul","content":"pub fn ul(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;ul&gt;` HTML element represents an unordered list of items, typically\n rendered as a bulleted list.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ul)\nSynonyms:\nsketch/redraw/dom/html.ul\nsketch/redraw/dom/html ul","url":"sketch/redraw/dom/html.html#ul"},{"doc":"sketch/redraw/dom/html","title":"var","content":"pub fn var(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;var&gt;` HTML element represents the name of a variable in a mathematical\n expression or a programming context. It&#39;s typically presented using an\n italicized version of the current typeface, although that behavior is\n browser-dependent.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/var)\nSynonyms:\nsketch/redraw/dom/html.var\nsketch/redraw/dom/html var","url":"sketch/redraw/dom/html.html#var"},{"doc":"sketch/redraw/dom/html","title":"video","content":"pub fn video(\n  class: Class,\n  attributes: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n The `&lt;video&gt;` HTML element embeds a media player which supports video\n playback into the document. You can use `&lt;video&gt;` for audio content as\n well, but the `&lt;audio&gt;` element may provide a more appropriate user experience.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/video)\nSynonyms:\nsketch/redraw/dom/html.video\nsketch/redraw/dom/html video","url":"sketch/redraw/dom/html.html#video"},{"doc":"sketch/redraw/dom/html","title":"wbr","content":"pub fn wbr(\n  class: Class,\n  attributes: List(Attribute),\n) -&gt; Component\n The `&lt;wbr&gt;` HTML element represents a word break opportunity—a position\n within text where the browser may optionally break a line, though its\n line-breaking rules would not otherwise create a break at that location.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/wbr)\nSynonyms:\nsketch/redraw/dom/html.wbr\nsketch/redraw/dom/html wbr","url":"sketch/redraw/dom/html.html#wbr"},{"doc":"sketch/redraw/dom/html","title":"sketch/redraw/dom/html","content":" This module is a drop-in replacement for `redraw/dom/html`. Just\n use the new functions, and everything will automagically be styled.\n Every stylable node has two functions: `[node]` and `[node]_`, the former\n applying a style, while the latter does not accept style, in case you don&#39;t\n need to style a node.","url":"sketch/redraw/dom/html.html"}]);